@@ -1,6 +1,7 @@
 #ifndef _GSTREAMERMM_H_
 #define _GSTREAMERMM_H_
 
+// Core includes
 #include <gstreamermm/bin.h>
 #include <gstreamermm/buffer.h>
 #include <gstreamermm/bus.h>
@@ -14,7 +15,7 @@
 #include <gstreamermm/event.h>
 #include <gstreamermm/filter.h>
 #include <gstreamermm/format.h>
-#include <gstreamermm/ghostpad.h>
+//TODO: #include <gstreamermm/ghostpad.h> (when bug #539108 is fixed)
 #include <gstreamermm/index.h>
 #include <gstreamermm/indexfactory.h>
 #include <gstreamermm/interface.h>
@@ -28,6 +29,7 @@
 #include <gstreamermm/plugin.h>
 #include <gstreamermm/pluginfeature.h>
 #include <gstreamermm/query.h>
+#include <gstreamermm/segment.h>
 #include <gstreamermm/structure.h>
 #include <gstreamermm/systemclock.h>
 #include <gstreamermm/taglist.h>
@@ -37,6 +39,12 @@
 #include <gstreamermm/value.h>
 #include <gstreamermm/xml.h>
 
+// Library base includes
+#include <gstreamermm/basesrc.h>
+#include <gstreamermm/basesink.h>
+#include <gstreamermm/basetransform.h>
+#include <gstreamermm/pushsrc.h>
+
 #include <gstreamermm/init.h>
 #include <gstreamermm/version.h>
 #include <gstreamermm/wrap_init.h>
