@@ -12,6 +12,7 @@
 
 // #include the widget headers so that we can call the get_type() static methods:
 
+#include "audioclock.h"
 #include "colorbalance.h"
 #include "colorbalancechannel.h"
 #include "xoverlay.h"
@@ -21,6 +22,7 @@ extern "C"
 
 //Declarations of the *_get_type() functions:
 
+GType gst_audio_clock_get_type(void);
 GType gst_color_balance_channel_get_type(void);
 
 //Declarations of the *_error_quark() functions:
@@ -30,6 +32,7 @@ GType gst_color_balance_channel_get_type(void);
 
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
+namespace GstBase {  class AudioClock_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace GstBase {  class ColorBalanceChannel_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 
 namespace GstBase { 
@@ -39,9 +42,11 @@ void wrap_init()
   // Register Error domains:
 
 // Map gtypes to gtkmm wrapper-creation functions:
+  Glib::wrap_register(gst_audio_clock_get_type(), &GstBase::AudioClock_Class::wrap_new);
   Glib::wrap_register(gst_color_balance_channel_get_type(), &GstBase::ColorBalanceChannel_Class::wrap_new);
 
   // Register the gtkmm gtypes:
+  GstBase::AudioClock::get_type();
   GstBase::ColorBalanceChannel::get_type();
 
 } // wrap_init()
